Class: Kubevirt::V1CPU

Inherits:
ApiModelBase show all
Defined in:
lib/kubevirt/models/v1_cpu.rb

Overview

CPU allows specifying the CPU topology.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V1CPU

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/kubevirt/models/v1_cpu.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1CPU` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1CPU`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cores')
    self.cores = attributes[:'cores']
  end

  if attributes.key?(:'dedicated_cpu_placement')
    self.dedicated_cpu_placement = attributes[:'dedicated_cpu_placement']
  end

  if attributes.key?(:'features')
    if (value = attributes[:'features']).is_a?(Array)
      self.features = value
    end
  end

  if attributes.key?(:'isolate_emulator_thread')
    self.isolate_emulator_thread = attributes[:'isolate_emulator_thread']
  end

  if attributes.key?(:'max_sockets')
    self.max_sockets = attributes[:'max_sockets']
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  end

  if attributes.key?(:'numa')
    self.numa = attributes[:'numa']
  end

  if attributes.key?(:'realtime')
    self.realtime = attributes[:'realtime']
  end

  if attributes.key?(:'sockets')
    self.sockets = attributes[:'sockets']
  end

  if attributes.key?(:'threads')
    self.threads = attributes[:'threads']
  end
end

Instance Attribute Details

#coresObject

Cores specifies the number of cores inside the vmi. Must be a value greater or equal 1.



20
21
22
# File 'lib/kubevirt/models/v1_cpu.rb', line 20

def cores
  @cores
end

#dedicated_cpu_placementObject

DedicatedCPUPlacement requests the scheduler to place the VirtualMachineInstance on a node with enough dedicated pCPUs and pin the vCPUs to it.



23
24
25
# File 'lib/kubevirt/models/v1_cpu.rb', line 23

def dedicated_cpu_placement
  @dedicated_cpu_placement
end

#featuresObject

Features specifies the CPU features list inside the VMI.



26
27
28
# File 'lib/kubevirt/models/v1_cpu.rb', line 26

def features
  @features
end

#isolate_emulator_threadObject

IsolateEmulatorThread requests one more dedicated pCPU to be allocated for the VMI to place the emulator thread on it.



29
30
31
# File 'lib/kubevirt/models/v1_cpu.rb', line 29

def isolate_emulator_thread
  @isolate_emulator_thread
end

#max_socketsObject

MaxSockets specifies the maximum amount of sockets that can be hotplugged



32
33
34
# File 'lib/kubevirt/models/v1_cpu.rb', line 32

def max_sockets
  @max_sockets
end

#modelObject

Model specifies the CPU model inside the VMI. List of available models https://github.com/libvirt/libvirt/tree/master/src/cpu_map. It is possible to specify special cases like "host-passthrough" to get the same CPU as the node and "host-model" to get CPU closest to the node one. Defaults to host-model.



35
36
37
# File 'lib/kubevirt/models/v1_cpu.rb', line 35

def model
  @model
end

#numaObject

Returns the value of attribute numa.



37
38
39
# File 'lib/kubevirt/models/v1_cpu.rb', line 37

def numa
  @numa
end

#realtimeObject

Returns the value of attribute realtime.



39
40
41
# File 'lib/kubevirt/models/v1_cpu.rb', line 39

def realtime
  @realtime
end

#socketsObject

Sockets specifies the number of sockets inside the vmi. Must be a value greater or equal 1.



42
43
44
# File 'lib/kubevirt/models/v1_cpu.rb', line 42

def sockets
  @sockets
end

#threadsObject

Threads specifies the number of threads inside the vmi. Must be a value greater or equal 1.



45
46
47
# File 'lib/kubevirt/models/v1_cpu.rb', line 45

def threads
  @threads
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/kubevirt/models/v1_cpu.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/kubevirt/models/v1_cpu.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/kubevirt/models/v1_cpu.rb', line 48

def self.attribute_map
  {
    :'cores' => :'cores',
    :'dedicated_cpu_placement' => :'dedicatedCpuPlacement',
    :'features' => :'features',
    :'isolate_emulator_thread' => :'isolateEmulatorThread',
    :'max_sockets' => :'maxSockets',
    :'model' => :'model',
    :'numa' => :'numa',
    :'realtime' => :'realtime',
    :'sockets' => :'sockets',
    :'threads' => :'threads'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/kubevirt/models/v1_cpu.rb', line 201

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/kubevirt/models/v1_cpu.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/kubevirt/models/v1_cpu.rb', line 74

def self.openapi_types
  {
    :'cores' => :'Integer',
    :'dedicated_cpu_placement' => :'Boolean',
    :'features' => :'Array<V1CPUFeature>',
    :'isolate_emulator_thread' => :'Boolean',
    :'max_sockets' => :'Integer',
    :'model' => :'String',
    :'numa' => :'V1NUMA',
    :'realtime' => :'V1Realtime',
    :'sockets' => :'Integer',
    :'threads' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/kubevirt/models/v1_cpu.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cores == o.cores &&
      dedicated_cpu_placement == o.dedicated_cpu_placement &&
      features == o.features &&
      isolate_emulator_thread == o.isolate_emulator_thread &&
      max_sockets == o.max_sockets &&
      model == o.model &&
      numa == o.numa &&
      realtime == o.realtime &&
      sockets == o.sockets &&
      threads == o.threads
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/kubevirt/models/v1_cpu.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/kubevirt/models/v1_cpu.rb', line 194

def hash
  [cores, dedicated_cpu_placement, features, isolate_emulator_thread, max_sockets, model, numa, realtime, sockets, threads].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
# File 'lib/kubevirt/models/v1_cpu.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/kubevirt/models/v1_cpu.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
# File 'lib/kubevirt/models/v1_cpu.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end