Class: Kubevirt::V1Network

Inherits:
ApiModelBase show all
Defined in:
lib/kubevirt/models/v1_network.rb

Overview

Network represents a network type and a resource that should be connected to the vm.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V1Network

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/kubevirt/models/v1_network.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1Network` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1Network`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'multus')
    self.multus = attributes[:'multus']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = ''
  end

  if attributes.key?(:'pod')
    self.pod = attributes[:'pod']
  end

  if attributes.key?(:'resource_claim')
    self.resource_claim = attributes[:'resource_claim']
  end
end

Instance Attribute Details

#multusObject

Returns the value of attribute multus.



19
20
21
# File 'lib/kubevirt/models/v1_network.rb', line 19

def multus
  @multus
end

#nameObject

Network name. Must be a DNS_LABEL and unique within the vm. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names



22
23
24
# File 'lib/kubevirt/models/v1_network.rb', line 22

def name
  @name
end

#podObject

Returns the value of attribute pod.



24
25
26
# File 'lib/kubevirt/models/v1_network.rb', line 24

def pod
  @pod
end

#resource_claimObject

Returns the value of attribute resource_claim.



26
27
28
# File 'lib/kubevirt/models/v1_network.rb', line 26

def resource_claim
  @resource_claim
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



39
40
41
# File 'lib/kubevirt/models/v1_network.rb', line 39

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/kubevirt/models/v1_network.rb', line 44

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/kubevirt/models/v1_network.rb', line 29

def self.attribute_map
  {
    :'multus' => :'multus',
    :'name' => :'name',
    :'pod' => :'pod',
    :'resource_claim' => :'resourceClaim'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/kubevirt/models/v1_network.rb', line 155

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
# File 'lib/kubevirt/models/v1_network.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
# File 'lib/kubevirt/models/v1_network.rb', line 49

def self.openapi_types
  {
    :'multus' => :'V1MultusNetwork',
    :'name' => :'String',
    :'pod' => :'V1PodNetwork',
    :'resource_claim' => :'V1ClaimRequest'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



131
132
133
134
135
136
137
138
# File 'lib/kubevirt/models/v1_network.rb', line 131

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      multus == o.multus &&
      name == o.name &&
      pod == o.pod &&
      resource_claim == o.resource_claim
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


142
143
144
# File 'lib/kubevirt/models/v1_network.rb', line 142

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



148
149
150
# File 'lib/kubevirt/models/v1_network.rb', line 148

def hash
  [multus, name, pod, resource_claim].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



101
102
103
104
105
106
107
108
109
# File 'lib/kubevirt/models/v1_network.rb', line 101

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/kubevirt/models/v1_network.rb', line 177

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



113
114
115
116
117
# File 'lib/kubevirt/models/v1_network.rb', line 113

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end