Class: Kubevirt::V1VirtualMachineExportLink
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Kubevirt::V1VirtualMachineExportLink
- Defined in:
- lib/kubevirt/models/v1_virtual_machine_export_link.rb
Overview
VirtualMachineExportLink contains a list of volumes available for export, as well as the URLs to obtain these volumes
Instance Attribute Summary collapse
-
#backups ⇒ Object
Backups is a list of available backups for the export.
-
#cert ⇒ Object
Cert is the public CA certificate base64 encoded.
-
#manifests ⇒ Object
Manifests is a list of available manifests for the export.
-
#volumes ⇒ Object
Volumes is a list of available volumes to export.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1VirtualMachineExportLink
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ V1VirtualMachineExportLink
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1VirtualMachineExportLink` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1VirtualMachineExportLink`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'backups') if (value = attributes[:'backups']).is_a?(Array) self.backups = value end end if attributes.key?(:'cert') self.cert = attributes[:'cert'] else self.cert = '' end if attributes.key?(:'manifests') if (value = attributes[:'manifests']).is_a?(Array) self.manifests = value end end if attributes.key?(:'volumes') if (value = attributes[:'volumes']).is_a?(Array) self.volumes = value end end end |
Instance Attribute Details
#backups ⇒ Object
Backups is a list of available backups for the export
20 21 22 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 20 def backups @backups end |
#cert ⇒ Object
Cert is the public CA certificate base64 encoded
23 24 25 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 23 def cert @cert end |
#manifests ⇒ Object
Manifests is a list of available manifests for the export
26 27 28 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 26 def manifests @manifests end |
#volumes ⇒ Object
Volumes is a list of available volumes to export
29 30 31 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 29 def volumes @volumes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 32 def self.attribute_map { :'backups' => :'backups', :'cert' => :'cert', :'manifests' => :'manifests', :'volumes' => :'volumes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 52 def self.openapi_types { :'backups' => :'Array<V1VirtualMachineExportBackup>', :'cert' => :'String', :'manifests' => :'Array<V1VirtualMachineExportManifest>', :'volumes' => :'Array<V1VirtualMachineExportVolume>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && backups == o.backups && cert == o.cert && manifests == o.manifests && volumes == o.volumes end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 157 def hash [backups, cert, manifests, volumes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @cert.nil? invalid_properties.push('invalid value for "cert", cert cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 126 |
# File 'lib/kubevirt/models/v1_virtual_machine_export_link.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @cert.nil? true end |