Class: Kubevirt::V1VirtualMachineInstanceMigrationState
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Kubevirt::V1VirtualMachineInstanceMigrationState
- Defined in:
- lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb
Instance Attribute Summary collapse
-
#abort_requested ⇒ Object
Indicates that the migration has been requested to abort.
-
#abort_status ⇒ Object
Indicates the final status of the live migration abortion.
-
#completed ⇒ Object
Indicates the migration completed.
-
#end_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON.
-
#failed ⇒ Object
Indicates that the migration failed.
-
#failure_reason ⇒ Object
Contains the reason why the migration failed.
-
#migration_configuration ⇒ Object
Returns the value of attribute migration_configuration.
-
#migration_network_type ⇒ Object
The type of migration network, either 'pod' or 'migration'.
-
#migration_policy_name ⇒ Object
Name of the migration policy.
-
#migration_uid ⇒ Object
The VirtualMachineInstanceMigration object associated with this migration.
-
#mode ⇒ Object
Lets us know if the vmi is currently running pre or post copy migration.
-
#source_node ⇒ Object
The source node that the VMI originated on.
-
#source_persistent_state_pvc_name ⇒ Object
If the VMI being migrated uses persistent features (backend-storage), its source PVC name is saved here.
-
#source_pod ⇒ Object
Returns the value of attribute source_pod.
-
#source_state ⇒ Object
Returns the value of attribute source_state.
-
#start_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON.
-
#target_attachment_pod_uid ⇒ Object
The UID of the target attachment pod for hotplug volumes.
-
#target_cpu_set ⇒ Object
If the VMI requires dedicated CPUs, this field will hold the dedicated CPU set on the target node.
-
#target_direct_migration_node_ports ⇒ Object
The list of ports opened for live migration on the destination node.
-
#target_memory_overhead ⇒ Object
Quantity is a fixed-point representation of a number.
-
#target_node ⇒ Object
The target node that the VMI is moving to.
-
#target_node_address ⇒ Object
The address of the target node to use for the migration.
-
#target_node_domain_detected ⇒ Object
The Target Node has seen the Domain Start Event.
-
#target_node_domain_ready_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON.
-
#target_node_topology ⇒ Object
If the VMI requires dedicated CPUs, this field will hold the numa topology on the target node.
-
#target_persistent_state_pvc_name ⇒ Object
If the VMI being migrated uses persistent features (backend-storage), its target PVC name is saved here.
-
#target_pod ⇒ Object
The target pod that the VMI is moving to.
-
#target_state ⇒ Object
Returns the value of attribute target_state.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1VirtualMachineInstanceMigrationState
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ V1VirtualMachineInstanceMigrationState
Initializes the object
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 184 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1VirtualMachineInstanceMigrationState` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1VirtualMachineInstanceMigrationState`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'abort_requested') self.abort_requested = attributes[:'abort_requested'] end if attributes.key?(:'abort_status') self.abort_status = attributes[:'abort_status'] end if attributes.key?(:'completed') self.completed = attributes[:'completed'] end if attributes.key?(:'end_timestamp') self. = attributes[:'end_timestamp'] end if attributes.key?(:'failed') self.failed = attributes[:'failed'] end if attributes.key?(:'failure_reason') self.failure_reason = attributes[:'failure_reason'] end if attributes.key?(:'migration_configuration') self.migration_configuration = attributes[:'migration_configuration'] end if attributes.key?(:'migration_network_type') self.migration_network_type = attributes[:'migration_network_type'] end if attributes.key?(:'migration_policy_name') self.migration_policy_name = attributes[:'migration_policy_name'] end if attributes.key?(:'migration_uid') self.migration_uid = attributes[:'migration_uid'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'source_node') self.source_node = attributes[:'source_node'] end if attributes.key?(:'source_persistent_state_pvc_name') self.source_persistent_state_pvc_name = attributes[:'source_persistent_state_pvc_name'] end if attributes.key?(:'source_pod') self.source_pod = attributes[:'source_pod'] end if attributes.key?(:'source_state') self.source_state = attributes[:'source_state'] end if attributes.key?(:'start_timestamp') self. = attributes[:'start_timestamp'] end if attributes.key?(:'target_attachment_pod_uid') self. = attributes[:'target_attachment_pod_uid'] end if attributes.key?(:'target_cpu_set') if (value = attributes[:'target_cpu_set']).is_a?(Array) self.target_cpu_set = value end end if attributes.key?(:'target_direct_migration_node_ports') if (value = attributes[:'target_direct_migration_node_ports']).is_a?(Hash) self.target_direct_migration_node_ports = value end end if attributes.key?(:'target_memory_overhead') self.target_memory_overhead = attributes[:'target_memory_overhead'] end if attributes.key?(:'target_node') self.target_node = attributes[:'target_node'] end if attributes.key?(:'target_node_address') self.target_node_address = attributes[:'target_node_address'] end if attributes.key?(:'target_node_domain_detected') self.target_node_domain_detected = attributes[:'target_node_domain_detected'] end if attributes.key?(:'target_node_domain_ready_timestamp') self. = attributes[:'target_node_domain_ready_timestamp'] end if attributes.key?(:'target_node_topology') self.target_node_topology = attributes[:'target_node_topology'] end if attributes.key?(:'target_persistent_state_pvc_name') self.target_persistent_state_pvc_name = attributes[:'target_persistent_state_pvc_name'] end if attributes.key?(:'target_pod') self.target_pod = attributes[:'target_pod'] end if attributes.key?(:'target_state') self.target_state = attributes[:'target_state'] end end |
Instance Attribute Details
#abort_requested ⇒ Object
Indicates that the migration has been requested to abort
19 20 21 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 19 def abort_requested @abort_requested end |
#abort_status ⇒ Object
Indicates the final status of the live migration abortion
22 23 24 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 22 def abort_status @abort_status end |
#completed ⇒ Object
Indicates the migration completed
25 26 27 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 25 def completed @completed end |
#end_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON. Wrappers are provided for many of the factory methods that the time package offers.
28 29 30 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 28 def @end_timestamp end |
#failed ⇒ Object
Indicates that the migration failed
31 32 33 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 31 def failed @failed end |
#failure_reason ⇒ Object
Contains the reason why the migration failed
34 35 36 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 34 def failure_reason @failure_reason end |
#migration_configuration ⇒ Object
Returns the value of attribute migration_configuration.
36 37 38 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 36 def migration_configuration @migration_configuration end |
#migration_network_type ⇒ Object
The type of migration network, either 'pod' or 'migration'
39 40 41 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 39 def migration_network_type @migration_network_type end |
#migration_policy_name ⇒ Object
Name of the migration policy. If string is empty, no policy is matched
42 43 44 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 42 def migration_policy_name @migration_policy_name end |
#migration_uid ⇒ Object
The VirtualMachineInstanceMigration object associated with this migration
45 46 47 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 45 def migration_uid @migration_uid end |
#mode ⇒ Object
Lets us know if the vmi is currently running pre or post copy migration
48 49 50 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 48 def mode @mode end |
#source_node ⇒ Object
The source node that the VMI originated on
51 52 53 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 51 def source_node @source_node end |
#source_persistent_state_pvc_name ⇒ Object
If the VMI being migrated uses persistent features (backend-storage), its source PVC name is saved here
54 55 56 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 54 def source_persistent_state_pvc_name @source_persistent_state_pvc_name end |
#source_pod ⇒ Object
Returns the value of attribute source_pod.
56 57 58 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 56 def source_pod @source_pod end |
#source_state ⇒ Object
Returns the value of attribute source_state.
58 59 60 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 58 def source_state @source_state end |
#start_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON. Wrappers are provided for many of the factory methods that the time package offers.
61 62 63 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 61 def @start_timestamp end |
#target_attachment_pod_uid ⇒ Object
The UID of the target attachment pod for hotplug volumes
64 65 66 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 64 def @target_attachment_pod_uid end |
#target_cpu_set ⇒ Object
If the VMI requires dedicated CPUs, this field will hold the dedicated CPU set on the target node
67 68 69 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 67 def target_cpu_set @target_cpu_set end |
#target_direct_migration_node_ports ⇒ Object
The list of ports opened for live migration on the destination node
70 71 72 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 70 def target_direct_migration_node_ports @target_direct_migration_node_ports end |
#target_memory_overhead ⇒ Object
Quantity is a fixed-point representation of a number. It provides convenient marshaling/unmarshaling in JSON and YAML, in addition to String() and AsInt64() accessors. The serialization format is: <quantity> ::= <signedNumber><suffix> (Note that <suffix> may be empty, from the \"\" case in <decimalSI>.) <digit> ::= 0 | 1 | ... | 9 <digits> ::= <digit> | <digit><digits> <number> ::= <digits> | <digits>.<digits> | <digits>. | .<digits> <sign> ::= \"+\" | \"-\" <signedNumber> ::= <number> | <sign><number> <suffix> ::= <binarySI> | <decimalExponent> | <decimalSI> <binarySI> ::= Ki | Mi | Gi | Ti | Pi | Ei (International System of units; See: http://physics.nist.gov/cuu/Units/binary.html) <decimalSI> ::= m | \"\" | k | M | G | T | P | E (Note that 1024 = 1Ki but 1000 = 1k; I didn't choose the capitalization.) <decimalExponent> ::= \"e\" <signedNumber> | \"E\" <signedNumber> No matter which of the three exponent forms is used, no quantity may represent a number greater than 2^63-1 in magnitude, nor may it have more than 3 decimal places. Numbers larger or more precise will be capped or rounded up. (E.g.: 0.1m will rounded up to 1m.) This may be extended in the future if we require larger or smaller quantities. When a Quantity is parsed from a string, it will remember the type of suffix it had, and will use the same type again when it is serialized. Before serializing, Quantity will be put in "canonical form". This means that Exponent/suffix will be adjusted up or down (with a corresponding increase or decrease in Mantissa) such that: - No precision is lost - No fractional digits will be emitted - The exponent (or suffix) is as large as possible. The sign will be omitted unless the number is negative. Examples: - 1.5 will be serialized as "1500m" - 1.5Gi will be serialized as "1536Mi" Note that the quantity will NEVER be internally represented by a floating point number. That is the whole point of this exercise. Non-canonical values will still parse as long as they are well formed, but will be re-emitted in their canonical form. (So always use canonical form, or don't diff.) This format is intended to make it difficult to use these numbers without writing some sort of special handling code in the hopes that that will cause implementors to also use a fixed point implementation.
73 74 75 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 73 def target_memory_overhead @target_memory_overhead end |
#target_node ⇒ Object
The target node that the VMI is moving to
76 77 78 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 76 def target_node @target_node end |
#target_node_address ⇒ Object
The address of the target node to use for the migration
79 80 81 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 79 def target_node_address @target_node_address end |
#target_node_domain_detected ⇒ Object
The Target Node has seen the Domain Start Event
82 83 84 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 82 def target_node_domain_detected @target_node_domain_detected end |
#target_node_domain_ready_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON. Wrappers are provided for many of the factory methods that the time package offers.
85 86 87 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 85 def @target_node_domain_ready_timestamp end |
#target_node_topology ⇒ Object
If the VMI requires dedicated CPUs, this field will hold the numa topology on the target node
88 89 90 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 88 def target_node_topology @target_node_topology end |
#target_persistent_state_pvc_name ⇒ Object
If the VMI being migrated uses persistent features (backend-storage), its target PVC name is saved here
91 92 93 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 91 def target_persistent_state_pvc_name @target_persistent_state_pvc_name end |
#target_pod ⇒ Object
The target pod that the VMI is moving to
94 95 96 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 94 def target_pod @target_pod end |
#target_state ⇒ Object
Returns the value of attribute target_state.
96 97 98 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 96 def target_state @target_state end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
133 134 135 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 133 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
138 139 140 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 138 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 99 def self.attribute_map { :'abort_requested' => :'abortRequested', :'abort_status' => :'abortStatus', :'completed' => :'completed', :'end_timestamp' => :'endTimestamp', :'failed' => :'failed', :'failure_reason' => :'failureReason', :'migration_configuration' => :'migrationConfiguration', :'migration_network_type' => :'migrationNetworkType', :'migration_policy_name' => :'migrationPolicyName', :'migration_uid' => :'migrationUid', :'mode' => :'mode', :'source_node' => :'sourceNode', :'source_persistent_state_pvc_name' => :'sourcePersistentStatePVCName', :'source_pod' => :'sourcePod', :'source_state' => :'sourceState', :'start_timestamp' => :'startTimestamp', :'target_attachment_pod_uid' => :'targetAttachmentPodUID', :'target_cpu_set' => :'targetCPUSet', :'target_direct_migration_node_ports' => :'targetDirectMigrationNodePorts', :'target_memory_overhead' => :'targetMemoryOverhead', :'target_node' => :'targetNode', :'target_node_address' => :'targetNodeAddress', :'target_node_domain_detected' => :'targetNodeDomainDetected', :'target_node_domain_ready_timestamp' => :'targetNodeDomainReadyTimestamp', :'target_node_topology' => :'targetNodeTopology', :'target_persistent_state_pvc_name' => :'targetPersistentStatePVCName', :'target_pod' => :'targetPod', :'target_state' => :'targetState' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 380 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
177 178 179 180 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 177 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 143 def self.openapi_types { :'abort_requested' => :'Boolean', :'abort_status' => :'String', :'completed' => :'Boolean', :'end_timestamp' => :'Time', :'failed' => :'Boolean', :'failure_reason' => :'String', :'migration_configuration' => :'V1VMIMConfigurationOptions', :'migration_network_type' => :'String', :'migration_policy_name' => :'String', :'migration_uid' => :'String', :'mode' => :'String', :'source_node' => :'String', :'source_persistent_state_pvc_name' => :'String', :'source_pod' => :'String', :'source_state' => :'V1VirtualMachineInstanceMigrationSourceState', :'start_timestamp' => :'Time', :'target_attachment_pod_uid' => :'String', :'target_cpu_set' => :'Array<Integer>', :'target_direct_migration_node_ports' => :'Hash<String, Integer>', :'target_memory_overhead' => :'Object', :'target_node' => :'String', :'target_node_address' => :'String', :'target_node_domain_detected' => :'Boolean', :'target_node_domain_ready_timestamp' => :'Time', :'target_node_topology' => :'String', :'target_persistent_state_pvc_name' => :'String', :'target_pod' => :'String', :'target_state' => :'V1VirtualMachineInstanceMigrationTargetState' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 332 def ==(o) return true if self.equal?(o) self.class == o.class && abort_requested == o.abort_requested && abort_status == o.abort_status && completed == o.completed && == o. && failed == o.failed && failure_reason == o.failure_reason && migration_configuration == o.migration_configuration && migration_network_type == o.migration_network_type && migration_policy_name == o.migration_policy_name && migration_uid == o.migration_uid && mode == o.mode && source_node == o.source_node && source_persistent_state_pvc_name == o.source_persistent_state_pvc_name && source_pod == o.source_pod && source_state == o.source_state && == o. && == o. && target_cpu_set == o.target_cpu_set && target_direct_migration_node_ports == o.target_direct_migration_node_ports && target_memory_overhead == o.target_memory_overhead && target_node == o.target_node && target_node_address == o.target_node_address && target_node_domain_detected == o.target_node_domain_detected && == o. && target_node_topology == o.target_node_topology && target_persistent_state_pvc_name == o.target_persistent_state_pvc_name && target_pod == o.target_pod && target_state == o.target_state end |
#eql?(o) ⇒ Boolean
367 368 369 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 367 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
373 374 375 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 373 def hash [abort_requested, abort_status, completed, , failed, failure_reason, migration_configuration, migration_network_type, migration_policy_name, migration_uid, mode, source_node, source_persistent_state_pvc_name, source_pod, source_state, , , target_cpu_set, target_direct_migration_node_ports, target_memory_overhead, target_node, target_node_address, target_node_domain_detected, , target_node_topology, target_persistent_state_pvc_name, target_pod, target_state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
317 318 319 320 321 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 317 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 402 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
325 326 327 328 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_migration_state.rb', line 325 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |