Class: Kubevirt::V1VirtualMachineInstanceNetworkInterface

Inherits:
Object
  • Object
show all
Defined in:
lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1VirtualMachineInstanceNetworkInterface

Initializes the object



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1VirtualMachineInstanceNetworkInterface` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1VirtualMachineInstanceNetworkInterface`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'info_source')
    self.info_source = attributes[:'info_source']
  end

  if attributes.key?(:'interface_name')
    self.interface_name = attributes[:'interface_name']
  end

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'ip_addresses')
    if (value = attributes[:'ip_addresses']).is_a?(Array)
      self.ip_addresses = value
    end
  end

  if attributes.key?(:'mac')
    self.mac = attributes[:'mac']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'pod_interface_name')
    self.pod_interface_name = attributes[:'pod_interface_name']
  end

  if attributes.key?(:'queue_count')
    self.queue_count = attributes[:'queue_count']
  end
end

Instance Attribute Details

#info_sourceObject

Specifies the origin of the interface data collected. values: domain, guest-agent, multus-status.



19
20
21
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 19

def info_source
  @info_source
end

#interface_nameObject

The interface name inside the Virtual Machine



22
23
24
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 22

def interface_name
  @interface_name
end

#ip_addressObject

IP address of a Virtual Machine interface. It is always the first item of IPs



25
26
27
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 25

def ip_address
  @ip_address
end

#ip_addressesObject

List of all IP addresses of a Virtual Machine interface



28
29
30
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 28

def ip_addresses
  @ip_addresses
end

#macObject

Hardware address of a Virtual Machine interface



31
32
33
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 31

def mac
  @mac
end

#nameObject

Name of the interface, corresponds to name of the network assigned to the interface



34
35
36
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 34

def name
  @name
end

#pod_interface_nameObject

PodInterfaceName represents the name of the pod network interface



37
38
39
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 37

def pod_interface_name
  @pod_interface_name
end

#queue_countObject

Specifies how many queues are allocated by MultiQueue



40
41
42
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 40

def queue_count
  @queue_count
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 200

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubevirt.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 57

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 43

def self.attribute_map
  {
    :'info_source' => :'infoSource',
    :'interface_name' => :'interfaceName',
    :'ip_address' => :'ipAddress',
    :'ip_addresses' => :'ipAddresses',
    :'mac' => :'mac',
    :'name' => :'name',
    :'pod_interface_name' => :'podInterfaceName',
    :'queue_count' => :'queueCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 62

def self.openapi_types
  {
    :'info_source' => :'String',
    :'interface_name' => :'String',
    :'ip_address' => :'String',
    :'ip_addresses' => :'Array<String>',
    :'mac' => :'String',
    :'name' => :'String',
    :'pod_interface_name' => :'String',
    :'queue_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      info_source == o.info_source &&
      interface_name == o.interface_name &&
      ip_address == o.ip_address &&
      ip_addresses == o.ip_addresses &&
      mac == o.mac &&
      name == o.name &&
      pod_interface_name == o.pod_interface_name &&
      queue_count == o.queue_count
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 271

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


163
164
165
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 163

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



169
170
171
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 169

def hash
  [info_source, interface_name, ip_address, ip_addresses, mac, name, pod_interface_name, queue_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



133
134
135
136
137
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



247
248
249
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 247

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



241
242
243
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 241

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



141
142
143
144
# File 'lib/kubevirt/models/v1_virtual_machine_instance_network_interface.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end