Class: Kubevirt::V1alpha1MigrationPolicySpec

Inherits:
ApiModelBase show all
Defined in:
lib/kubevirt/models/v1alpha1_migration_policy_spec.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V1alpha1MigrationPolicySpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1alpha1MigrationPolicySpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1alpha1MigrationPolicySpec`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allow_auto_converge')
    self.allow_auto_converge = attributes[:'allow_auto_converge']
  end

  if attributes.key?(:'allow_post_copy')
    self.allow_post_copy = attributes[:'allow_post_copy']
  end

  if attributes.key?(:'allow_workload_disruption')
    self.allow_workload_disruption = attributes[:'allow_workload_disruption']
  end

  if attributes.key?(:'bandwidth_per_migration')
    self.bandwidth_per_migration = attributes[:'bandwidth_per_migration']
  end

  if attributes.key?(:'completion_timeout_per_gi_b')
    self.completion_timeout_per_gi_b = attributes[:'completion_timeout_per_gi_b']
  end

  if attributes.key?(:'experimental')
    self.experimental = attributes[:'experimental']
  end

  if attributes.key?(:'max_downtime_ms')
    self.max_downtime_ms = attributes[:'max_downtime_ms']
  end

  if attributes.key?(:'selectors')
    self.selectors = attributes[:'selectors']
  else
    self.selectors = nil
  end
end

Instance Attribute Details

#allow_auto_convergeObject

Returns the value of attribute allow_auto_converge.



18
19
20
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 18

def allow_auto_converge
  @allow_auto_converge
end

#allow_post_copyObject

Returns the value of attribute allow_post_copy.



20
21
22
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 20

def allow_post_copy
  @allow_post_copy
end

#allow_workload_disruptionObject

Returns the value of attribute allow_workload_disruption.



22
23
24
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 22

def allow_workload_disruption
  @allow_workload_disruption
end

#bandwidth_per_migrationObject

Quantity is a fixed-point representation of a number. It provides convenient marshaling/unmarshaling in JSON and YAML, in addition to String() and AsInt64() accessors. The serialization format is: <quantity> ::= <signedNumber><suffix> (Note that <suffix> may be empty, from the \"\" case in <decimalSI>.) <digit> ::= 0 | 1 | ... | 9 <digits> ::= <digit> | <digit><digits> <number> ::= <digits> | <digits>.<digits> | <digits>. | .<digits> <sign> ::= \"+\" | \"-\" <signedNumber> ::= <number> | <sign><number> <suffix> ::= <binarySI> | <decimalExponent> | <decimalSI> <binarySI> ::= Ki | Mi | Gi | Ti | Pi | Ei (International System of units; See: http://physics.nist.gov/cuu/Units/binary.html) <decimalSI> ::= m | \"\" | k | M | G | T | P | E (Note that 1024 = 1Ki but 1000 = 1k; I didn't choose the capitalization.) <decimalExponent> ::= \"e\" <signedNumber> | \"E\" <signedNumber> No matter which of the three exponent forms is used, no quantity may represent a number greater than 2^63-1 in magnitude, nor may it have more than 3 decimal places. Numbers larger or more precise will be capped or rounded up. (E.g.: 0.1m will rounded up to 1m.) This may be extended in the future if we require larger or smaller quantities. When a Quantity is parsed from a string, it will remember the type of suffix it had, and will use the same type again when it is serialized. Before serializing, Quantity will be put in "canonical form". This means that Exponent/suffix will be adjusted up or down (with a corresponding increase or decrease in Mantissa) such that: - No precision is lost - No fractional digits will be emitted - The exponent (or suffix) is as large as possible. The sign will be omitted unless the number is negative. Examples: - 1.5 will be serialized as "1500m" - 1.5Gi will be serialized as "1536Mi" Note that the quantity will NEVER be internally represented by a floating point number. That is the whole point of this exercise. Non-canonical values will still parse as long as they are well formed, but will be re-emitted in their canonical form. (So always use canonical form, or don't diff.) This format is intended to make it difficult to use these numbers without writing some sort of special handling code in the hopes that that will cause implementors to also use a fixed point implementation.



25
26
27
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 25

def bandwidth_per_migration
  @bandwidth_per_migration
end

#completion_timeout_per_gi_bObject

Returns the value of attribute completion_timeout_per_gi_b.



27
28
29
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 27

def completion_timeout_per_gi_b
  @completion_timeout_per_gi_b
end

#experimentalObject

Returns the value of attribute experimental.



29
30
31
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 29

def experimental
  @experimental
end

#max_downtime_msObject

Returns the value of attribute max_downtime_ms.



31
32
33
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 31

def max_downtime_ms
  @max_downtime_ms
end

#selectorsObject

Returns the value of attribute selectors.



33
34
35
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 33

def selectors
  @selectors
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 36

def self.attribute_map
  {
    :'allow_auto_converge' => :'allowAutoConverge',
    :'allow_post_copy' => :'allowPostCopy',
    :'allow_workload_disruption' => :'allowWorkloadDisruption',
    :'bandwidth_per_migration' => :'bandwidthPerMigration',
    :'completion_timeout_per_gi_b' => :'completionTimeoutPerGiB',
    :'experimental' => :'experimental',
    :'max_downtime_ms' => :'maxDowntimeMs',
    :'selectors' => :'selectors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 190

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 60

def self.openapi_types
  {
    :'allow_auto_converge' => :'Boolean',
    :'allow_post_copy' => :'Boolean',
    :'allow_workload_disruption' => :'Boolean',
    :'bandwidth_per_migration' => :'Object',
    :'completion_timeout_per_gi_b' => :'Integer',
    :'experimental' => :'V1ExperimentalMigrationOptions',
    :'max_downtime_ms' => :'Integer',
    :'selectors' => :'V1alpha1Selectors'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allow_auto_converge == o.allow_auto_converge &&
      allow_post_copy == o.allow_post_copy &&
      allow_workload_disruption == o.allow_workload_disruption &&
      bandwidth_per_migration == o.bandwidth_per_migration &&
      completion_timeout_per_gi_b == o.completion_timeout_per_gi_b &&
      experimental == o.experimental &&
      max_downtime_ms == o.max_downtime_ms &&
      selectors == o.selectors
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 177

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



183
184
185
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 183

def hash
  [allow_auto_converge, allow_post_copy, allow_workload_disruption, bandwidth_per_migration, completion_timeout_per_gi_b, experimental, max_downtime_ms, selectors].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @selectors.nil?
    invalid_properties.push('invalid value for "selectors", selectors cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
# File 'lib/kubevirt/models/v1alpha1_migration_policy_spec.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @selectors.nil?
  true
end