Class: Kubevirt::V1alpha1VirtualMachineBackupSpec

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb

Overview

VirtualMachineBackupSpec is the spec for a VirtualMachineBackup resource

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V1alpha1VirtualMachineBackupSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1alpha1VirtualMachineBackupSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1alpha1VirtualMachineBackupSpec`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'force_full_backup')
    self.force_full_backup = attributes[:'force_full_backup']
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'pvc_name')
    self.pvc_name = attributes[:'pvc_name']
  end

  if attributes.key?(:'skip_quiesce')
    self.skip_quiesce = attributes[:'skip_quiesce']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  else
    self.source = nil
  end

  if attributes.key?(:'token_secret_ref')
    self.token_secret_ref = attributes[:'token_secret_ref']
  end

  if attributes.key?(:'ttl_duration')
    self.ttl_duration = attributes[:'ttl_duration']
  end
end

Instance Attribute Details

#force_full_backupObject

ForceFullBackup indicates that a full backup is desired



20
21
22
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 20

def force_full_backup
  @force_full_backup
end

#modeObject

Mode specifies the way the backup output will be recieved



23
24
25
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 23

def mode
  @mode
end

#pvc_nameObject

PvcName required in push mode. Specifies the name of the PVC where the backup output will be stored



26
27
28
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 26

def pvc_name
  @pvc_name
end

#skip_quiesceObject

SkipQuiesce indicates whether the VM's filesystem shoule not be quiesced before the backup



29
30
31
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 29

def skip_quiesce
  @skip_quiesce
end

#sourceObject

Returns the value of attribute source.



31
32
33
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 31

def source
  @source
end

#token_secret_refObject

TokenSecretRef is the name of the secret that will be used to pull the backup from an associated endpoint



34
35
36
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 34

def token_secret_ref
  @token_secret_ref
end

#ttl_durationObject

Duration is a wrapper around time.Duration which supports correct marshaling to YAML and JSON. In particular, it marshals into strings, which can be used as map keys in json.



37
38
39
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 37

def ttl_duration
  @ttl_duration
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 40

def self.attribute_map
  {
    :'force_full_backup' => :'forceFullBackup',
    :'mode' => :'mode',
    :'pvc_name' => :'pvcName',
    :'skip_quiesce' => :'skipQuiesce',
    :'source' => :'source',
    :'token_secret_ref' => :'tokenSecretRef',
    :'ttl_duration' => :'ttlDuration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 187

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 63

def self.openapi_types
  {
    :'force_full_backup' => :'Boolean',
    :'mode' => :'String',
    :'pvc_name' => :'String',
    :'skip_quiesce' => :'Boolean',
    :'source' => :'K8sIoApiCoreV1TypedLocalObjectReference',
    :'token_secret_ref' => :'String',
    :'ttl_duration' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



160
161
162
163
164
165
166
167
168
169
170
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      force_full_backup == o.force_full_backup &&
      mode == o.mode &&
      pvc_name == o.pvc_name &&
      skip_quiesce == o.skip_quiesce &&
      source == o.source &&
      token_secret_ref == o.token_secret_ref &&
      ttl_duration == o.ttl_duration
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 180

def hash
  [force_full_backup, mode, pvc_name, skip_quiesce, source, token_secret_ref, ttl_duration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_spec.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @source.nil?
  true
end