Class: Kubevirt::V1beta1VirtualMachineCloneSpec

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V1beta1VirtualMachineCloneSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1beta1VirtualMachineCloneSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1beta1VirtualMachineCloneSpec`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'annotation_filters')
    if (value = attributes[:'annotation_filters']).is_a?(Array)
      self.annotation_filters = value
    end
  end

  if attributes.key?(:'label_filters')
    if (value = attributes[:'label_filters']).is_a?(Array)
      self.label_filters = value
    end
  end

  if attributes.key?(:'new_mac_addresses')
    if (value = attributes[:'new_mac_addresses']).is_a?(Hash)
      self.new_mac_addresses = value
    end
  end

  if attributes.key?(:'new_sm_bios_serial')
    self.new_sm_bios_serial = attributes[:'new_sm_bios_serial']
  end

  if attributes.key?(:'patches')
    if (value = attributes[:'patches']).is_a?(Array)
      self.patches = value
    end
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  else
    self.source = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end

  if attributes.key?(:'volume_name_policy')
    self.volume_name_policy = attributes[:'volume_name_policy']
  end
end

Instance Attribute Details

#annotation_filtersObject

Example use: "!some/key*". For a detailed description, please refer to https://kubevirt.io/user-guide/operations/clone_api/#label-annotation-filters.



19
20
21
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 19

def annotation_filters
  @annotation_filters
end

#label_filtersObject

Example use: "!some/key*". For a detailed description, please refer to https://kubevirt.io/user-guide/operations/clone_api/#label-annotation-filters.



22
23
24
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 22

def label_filters
  @label_filters
end

#new_mac_addressesObject

NewMacAddresses manually sets that target interfaces' mac addresses. The key is the interface name and the value is the new mac address. If this field is not specified, a new MAC address will be generated automatically, as for any interface that is not included in this map.



25
26
27
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 25

def new_mac_addresses
  @new_mac_addresses
end

#new_sm_bios_serialObject

NewSMBiosSerial manually sets that target's SMbios serial. If this field is not specified, a new serial will be generated automatically.



28
29
30
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 28

def new_sm_bios_serial
  @new_sm_bios_serial
end

#patchesObject

Patches holds JSON patches to apply to target. Patches should fit the target's Kind. Example: '\"add\", \"path\": \"/spec/template/metadata/labels/example\", \"value\": \"new-label\"'



31
32
33
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 31

def patches
  @patches
end

#sourceObject

Returns the value of attribute source.



33
34
35
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 33

def source
  @source
end

#targetObject

Returns the value of attribute target.



35
36
37
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 35

def target
  @target
end

#templateObject

Returns the value of attribute template.



37
38
39
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 37

def template
  @template
end

#volume_name_policyObject

VolumeNamePolicy defines how to handle volume naming during the clone operation



40
41
42
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 40

def volume_name_policy
  @volume_name_policy
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 43

def self.attribute_map
  {
    :'annotation_filters' => :'annotationFilters',
    :'label_filters' => :'labelFilters',
    :'new_mac_addresses' => :'newMacAddresses',
    :'new_sm_bios_serial' => :'newSMBiosSerial',
    :'patches' => :'patches',
    :'source' => :'source',
    :'target' => :'target',
    :'template' => :'template',
    :'volume_name_policy' => :'volumeNamePolicy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 68

def self.openapi_types
  {
    :'annotation_filters' => :'Array<String>',
    :'label_filters' => :'Array<String>',
    :'new_mac_addresses' => :'Hash<String, String>',
    :'new_sm_bios_serial' => :'String',
    :'patches' => :'Array<String>',
    :'source' => :'K8sIoApiCoreV1TypedLocalObjectReference',
    :'target' => :'K8sIoApiCoreV1TypedLocalObjectReference',
    :'template' => :'V1beta1VirtualMachineCloneTemplateFilters',
    :'volume_name_policy' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      annotation_filters == o.annotation_filters &&
      label_filters == o.label_filters &&
      new_mac_addresses == o.new_mac_addresses &&
      new_sm_bios_serial == o.new_sm_bios_serial &&
      patches == o.patches &&
      source == o.source &&
      target == o.target &&
      template == o.template &&
      volume_name_policy == o.volume_name_policy
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



205
206
207
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 205

def hash
  [annotation_filters, label_filters, new_mac_addresses, new_sm_bios_serial, patches, source, target, template, volume_name_policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
# File 'lib/kubevirt/models/v1beta1_virtual_machine_clone_spec.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @source.nil?
  true
end