Class: Kubevirt::V1DomainSpec
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Kubevirt::V1DomainSpec
- Defined in:
- lib/kubevirt/models/v1_domain_spec.rb
Instance Attribute Summary collapse
-
#chassis ⇒ Object
Returns the value of attribute chassis.
-
#clock ⇒ Object
Returns the value of attribute clock.
-
#cpu ⇒ Object
Returns the value of attribute cpu.
-
#devices ⇒ Object
Returns the value of attribute devices.
-
#features ⇒ Object
Returns the value of attribute features.
-
#firmware ⇒ Object
Returns the value of attribute firmware.
-
#io_threads ⇒ Object
Returns the value of attribute io_threads.
-
#io_threads_policy ⇒ Object
Controls whether or not disks will share IOThreads.
-
#launch_security ⇒ Object
Returns the value of attribute launch_security.
-
#machine ⇒ Object
Returns the value of attribute machine.
-
#memory ⇒ Object
Returns the value of attribute memory.
-
#reboot_policy ⇒ Object
RebootPolicy specifies how the guest should behave on reboot.
-
#resources ⇒ Object
Returns the value of attribute resources.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1DomainSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ V1DomainSpec
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1DomainSpec` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1DomainSpec`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'chassis') self.chassis = attributes[:'chassis'] end if attributes.key?(:'clock') self.clock = attributes[:'clock'] end if attributes.key?(:'cpu') self.cpu = attributes[:'cpu'] end if attributes.key?(:'devices') self.devices = attributes[:'devices'] else self.devices = nil end if attributes.key?(:'features') self.features = attributes[:'features'] end if attributes.key?(:'firmware') self.firmware = attributes[:'firmware'] end if attributes.key?(:'io_threads') self.io_threads = attributes[:'io_threads'] end if attributes.key?(:'io_threads_policy') self.io_threads_policy = attributes[:'io_threads_policy'] end if attributes.key?(:'launch_security') self.launch_security = attributes[:'launch_security'] end if attributes.key?(:'machine') self.machine = attributes[:'machine'] end if attributes.key?(:'memory') self.memory = attributes[:'memory'] end if attributes.key?(:'reboot_policy') self.reboot_policy = attributes[:'reboot_policy'] end if attributes.key?(:'resources') self.resources = attributes[:'resources'] end end |
Instance Attribute Details
#chassis ⇒ Object
Returns the value of attribute chassis.
18 19 20 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 18 def chassis @chassis end |
#clock ⇒ Object
Returns the value of attribute clock.
20 21 22 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 20 def clock @clock end |
#cpu ⇒ Object
Returns the value of attribute cpu.
22 23 24 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 22 def cpu @cpu end |
#devices ⇒ Object
Returns the value of attribute devices.
24 25 26 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 24 def devices @devices end |
#features ⇒ Object
Returns the value of attribute features.
26 27 28 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 26 def features @features end |
#firmware ⇒ Object
Returns the value of attribute firmware.
28 29 30 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 28 def firmware @firmware end |
#io_threads ⇒ Object
Returns the value of attribute io_threads.
30 31 32 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 30 def io_threads @io_threads end |
#io_threads_policy ⇒ Object
Controls whether or not disks will share IOThreads. Omitting IOThreadsPolicy disables use of IOThreads. One of: shared, auto, supplementalPool
33 34 35 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 33 def io_threads_policy @io_threads_policy end |
#launch_security ⇒ Object
Returns the value of attribute launch_security.
35 36 37 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 35 def launch_security @launch_security end |
#machine ⇒ Object
Returns the value of attribute machine.
37 38 39 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 37 def machine @machine end |
#memory ⇒ Object
Returns the value of attribute memory.
39 40 41 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 39 def memory @memory end |
#reboot_policy ⇒ Object
RebootPolicy specifies how the guest should behave on reboot. Reboot (default): The guest is allowed to reboot silently. Terminate: The VMI will be terminated on guest reboot, allowing higher level controllers (such as the VM controller) to recreate the VMI with any updated configuration such as boot order changes.
42 43 44 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 42 def reboot_policy @reboot_policy end |
#resources ⇒ Object
Returns the value of attribute resources.
44 45 46 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 44 def resources @resources end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 47 def self.attribute_map { :'chassis' => :'chassis', :'clock' => :'clock', :'cpu' => :'cpu', :'devices' => :'devices', :'features' => :'features', :'firmware' => :'firmware', :'io_threads' => :'ioThreads', :'io_threads_policy' => :'ioThreadsPolicy', :'launch_security' => :'launchSecurity', :'machine' => :'machine', :'memory' => :'memory', :'reboot_policy' => :'rebootPolicy', :'resources' => :'resources' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 236 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 76 def self.openapi_types { :'chassis' => :'V1Chassis', :'clock' => :'V1Clock', :'cpu' => :'V1CPU', :'devices' => :'V1Devices', :'features' => :'V1Features', :'firmware' => :'V1Firmware', :'io_threads' => :'V1DiskIOThreads', :'io_threads_policy' => :'String', :'launch_security' => :'V1LaunchSecurity', :'machine' => :'V1Machine', :'memory' => :'V1Memory', :'reboot_policy' => :'String', :'resources' => :'V1ResourceRequirements' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && chassis == o.chassis && clock == o.clock && cpu == o.cpu && devices == o.devices && features == o.features && firmware == o.firmware && io_threads == o.io_threads && io_threads_policy == o.io_threads_policy && launch_security == o.launch_security && machine == o.machine && memory == o.memory && reboot_policy == o.reboot_policy && resources == o.resources end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 229 def hash [chassis, clock, cpu, devices, features, firmware, io_threads, io_threads_policy, launch_security, machine, memory, reboot_policy, resources].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @devices.nil? invalid_properties.push('invalid value for "devices", devices cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 189 |
# File 'lib/kubevirt/models/v1_domain_spec.rb', line 185 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @devices.nil? true end |