Class: Kubevirt::V1VirtualMachineInstanceBackupStatus
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Kubevirt::V1VirtualMachineInstanceBackupStatus
- Defined in:
- lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb
Overview
VirtualMachineInstanceBackupStatus tracks the information of the executed backup
Instance Attribute Summary collapse
-
#backup_msg ⇒ Object
BackupMsg resturns any relevant information like failure reason unfreeze failed etc...
-
#backup_name ⇒ Object
BackupName is the name of the executed backup.
-
#checkpoint_name ⇒ Object
CheckpointName is the name of the checkpoint created for the backup.
-
#completed ⇒ Object
Completed indicates the backup completed.
-
#end_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON.
-
#failed ⇒ Object
Failed indicates that the backup failed.
-
#quiesce_status ⇒ Object
QuiesceStatus indicates whether filesystem freeze succeeded, failed, or was skipped.
-
#start_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON.
-
#volumes ⇒ Object
Volumes lists the volumes included in the backup.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1VirtualMachineInstanceBackupStatus
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ V1VirtualMachineInstanceBackupStatus
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1VirtualMachineInstanceBackupStatus` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1VirtualMachineInstanceBackupStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'backup_msg') self.backup_msg = attributes[:'backup_msg'] end if attributes.key?(:'backup_name') self.backup_name = attributes[:'backup_name'] end if attributes.key?(:'checkpoint_name') self.checkpoint_name = attributes[:'checkpoint_name'] end if attributes.key?(:'completed') self.completed = attributes[:'completed'] end if attributes.key?(:'end_timestamp') self. = attributes[:'end_timestamp'] end if attributes.key?(:'failed') self.failed = attributes[:'failed'] end if attributes.key?(:'quiesce_status') self.quiesce_status = attributes[:'quiesce_status'] end if attributes.key?(:'start_timestamp') self. = attributes[:'start_timestamp'] end if attributes.key?(:'volumes') if (value = attributes[:'volumes']).is_a?(Array) self.volumes = value end end end |
Instance Attribute Details
#backup_msg ⇒ Object
BackupMsg resturns any relevant information like failure reason unfreeze failed etc...
20 21 22 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 20 def backup_msg @backup_msg end |
#backup_name ⇒ Object
BackupName is the name of the executed backup
23 24 25 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 23 def backup_name @backup_name end |
#checkpoint_name ⇒ Object
CheckpointName is the name of the checkpoint created for the backup
26 27 28 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 26 def checkpoint_name @checkpoint_name end |
#completed ⇒ Object
Completed indicates the backup completed
29 30 31 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 29 def completed @completed end |
#end_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON. Wrappers are provided for many of the factory methods that the time package offers.
32 33 34 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 32 def @end_timestamp end |
#failed ⇒ Object
Failed indicates that the backup failed
35 36 37 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 35 def failed @failed end |
#quiesce_status ⇒ Object
QuiesceStatus indicates whether filesystem freeze succeeded, failed, or was skipped.
38 39 40 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 38 def quiesce_status @quiesce_status end |
#start_timestamp ⇒ Object
Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON. Wrappers are provided for many of the factory methods that the time package offers.
41 42 43 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 41 def @start_timestamp end |
#volumes ⇒ Object
Volumes lists the volumes included in the backup
44 45 46 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 44 def volumes @volumes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 47 def self.attribute_map { :'backup_msg' => :'backupMsg', :'backup_name' => :'backupName', :'checkpoint_name' => :'checkpointName', :'completed' => :'completed', :'end_timestamp' => :'endTimestamp', :'failed' => :'failed', :'quiesce_status' => :'quiesceStatus', :'start_timestamp' => :'startTimestamp', :'volumes' => :'volumes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 193 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 72 def self.openapi_types { :'backup_msg' => :'String', :'backup_name' => :'String', :'checkpoint_name' => :'String', :'completed' => :'Boolean', :'end_timestamp' => :'Time', :'failed' => :'Boolean', :'quiesce_status' => :'String', :'start_timestamp' => :'Time', :'volumes' => :'Array<V1VirtualMachineInstanceBackupVolumeInfo>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && backup_msg == o.backup_msg && backup_name == o.backup_name && checkpoint_name == o.checkpoint_name && completed == o.completed && == o. && failed == o.failed && quiesce_status == o.quiesce_status && == o. && volumes == o.volumes end |
#eql?(o) ⇒ Boolean
180 181 182 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 180 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 186 def hash [backup_msg, backup_name, checkpoint_name, completed, , failed, quiesce_status, , volumes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 149 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 |
# File 'lib/kubevirt/models/v1_virtual_machine_instance_backup_status.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |