Class: Kubevirt::V1alpha1VirtualMachineBackupStatus
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Kubevirt::V1alpha1VirtualMachineBackupStatus
- Defined in:
- lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb
Overview
VirtualMachineBackupStatus is the status for a VirtualMachineBackup resource
Instance Attribute Summary collapse
-
#checkpoint_name ⇒ Object
CheckpointName the name of the checkpoint created for the current backup.
-
#conditions ⇒ Object
Returns the value of attribute conditions.
-
#endpoint_cert ⇒ Object
EndpointCert is the raw CACert that is to be used when connecting to an exported backup endpoint in pull mode.
-
#export_uid ⇒ Object
ExportUID tracks the UID of the associated VMExport for pull-mode backups used to detect VMExport recreation and re-initiate the export handshake.
-
#included_volumes ⇒ Object
IncludedVolumes lists the volumes that were included in the backup.
-
#type ⇒ Object
Type indicates if the backup was full or incremental.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1alpha1VirtualMachineBackupStatus
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ V1alpha1VirtualMachineBackupStatus
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubevirt::V1alpha1VirtualMachineBackupStatus` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubevirt::V1alpha1VirtualMachineBackupStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'checkpoint_name') self.checkpoint_name = attributes[:'checkpoint_name'] end if attributes.key?(:'conditions') if (value = attributes[:'conditions']).is_a?(Array) self.conditions = value end end if attributes.key?(:'endpoint_cert') self.endpoint_cert = attributes[:'endpoint_cert'] end if attributes.key?(:'export_uid') self.export_uid = attributes[:'export_uid'] end if attributes.key?(:'included_volumes') if (value = attributes[:'included_volumes']).is_a?(Array) self.included_volumes = value end end if attributes.key?(:'type') self.type = attributes[:'type'] end end |
Instance Attribute Details
#checkpoint_name ⇒ Object
CheckpointName the name of the checkpoint created for the current backup
20 21 22 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 20 def checkpoint_name @checkpoint_name end |
#conditions ⇒ Object
Returns the value of attribute conditions.
22 23 24 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 22 def conditions @conditions end |
#endpoint_cert ⇒ Object
EndpointCert is the raw CACert that is to be used when connecting to an exported backup endpoint in pull mode.
25 26 27 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 25 def endpoint_cert @endpoint_cert end |
#export_uid ⇒ Object
ExportUID tracks the UID of the associated VMExport for pull-mode backups used to detect VMExport recreation and re-initiate the export handshake
28 29 30 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 28 def export_uid @export_uid end |
#included_volumes ⇒ Object
IncludedVolumes lists the volumes that were included in the backup
31 32 33 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 31 def included_volumes @included_volumes end |
#type ⇒ Object
Type indicates if the backup was full or incremental
34 35 36 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 34 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 37 def self.attribute_map { :'checkpoint_name' => :'checkpointName', :'conditions' => :'conditions', :'endpoint_cert' => :'endpointCert', :'export_uid' => :'exportUID', :'included_volumes' => :'includedVolumes', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 59 def self.openapi_types { :'checkpoint_name' => :'String', :'conditions' => :'Array<K8sIoApimachineryPkgApisMetaV1Condition>', :'endpoint_cert' => :'String', :'export_uid' => :'String', :'included_volumes' => :'Array<V1alpha1BackupVolumeInfo>', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && checkpoint_name == o.checkpoint_name && conditions == o.conditions && endpoint_cert == o.endpoint_cert && export_uid == o.export_uid && included_volumes == o.included_volumes && type == o.type end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 157 def hash [checkpoint_name, conditions, endpoint_cert, export_uid, included_volumes, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 |
# File 'lib/kubevirt/models/v1alpha1_virtual_machine_backup_status.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |